==> haskell-crypto-token-0.0.2-36-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-token.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypto-token
version:              0.0.2
visibility:           public
id:                   crypto-token-0.0.2-8SNTbZKActKLYyt95SgZeW
key:                  crypto-token-0.0.2-8SNTbZKActKLYyt95SgZeW
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             crypto tokens
description:          Encrypted tokens/tickets to keep state in the client side.
category:             Cryptography, Network
abi:                  2e05dd7285f6cb7a7838c22375cd1f81
exposed:              True
exposed-modules:      Crypto.Token
import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypto-token-0.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypto-token-0.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypto-token-0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypto-token
hs-libraries:         HScrypto-token-0.0.2-8SNTbZKActKLYyt95SgZeW
depends:
    array-0.5.4.0 base-4.17.2.1 crypton-0.34-3draoabVYue3tm8di5n8kF
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt

haddock-interfaces:
    /usr/share/doc/haskell-crypto-token/html/crypto-token.haddock

haddock-html:         /usr/share/doc/haskell-crypto-token/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-token-0.0.2-39-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-token.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypto-token
version:              0.0.2
visibility:           public
id:                   crypto-token-0.0.2-CbBGNdBrPHe4LTV4XLMXzE
key:                  crypto-token-0.0.2-CbBGNdBrPHe4LTV4XLMXzE
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             crypto tokens
description:          Encrypted tokens/tickets to keep state in the client side.
category:             Cryptography, Network
abi:                  dd29a0961a547b6ba04c0074102a7eca
exposed:              True
exposed-modules:      Crypto.Token
import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypto-token-0.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypto-token-0.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypto-token-0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypto-token
hs-libraries:         HScrypto-token-0.0.2-CbBGNdBrPHe4LTV4XLMXzE
depends:
    array-0.5.4.0 base-4.17.2.1 crypton-1.0.0-16haeL77tcL2BdZpDixsER
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt

haddock-interfaces:
    /usr/share/doc/haskell-crypto-token/html/crypto-token.haddock

haddock-html:         /usr/share/doc/haskell-crypto-token/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
